package md

const ZhiosOrdersEsIndex = "zhios_orders"

/**
Cluster 集群(一个ES集群由一个或多个节点（Node）组成，每个集群都有一个cluster name作为标识。)
node 节点(一个ES实例就是一个node。)
number_of_shards 主分片(是指索引要做多少个分片，只能在创建索引时指定，后期无法修改。)
number_of_replicas 副分片(是指每个分片有多少个副本，后期可以动态修改。)
TODO::一般情况下，集群所有索引的副本最大值+1 <= 集群节点数量 <= 分片数量
*/

const ZhiosOrdersEsMapping = `
{ 
	"settings" : {
      "number_of_shards" : 2,
      "number_of_replicas" : 1 
    },
	"mappings":{
		"properties":{
			"master_id":{
				"type": "integer"
			},
			"ord_id":{
				"type": "keyword"
			},
			"main_ord_id":{
				"type": "keyword"
			},
			"store_ord_id":{
				"type": "keyword"
			},
			"goods_id":{
				"type": "keyword"
			},
			"uid":{
				"type": "integer"
			},
			"buyer_phone":{
				"type": "keyword"
			},
			"cost_price":{
				"type": "float"
			},
			"state":{
				"type": "integer"
			},
			"state_zh":{
				"type": "keyword"
			},
			"pay_time":{
				"type": "date",
         		"format": "yyyy-MM-dd HH:mm:ss||yyyy-MM-dd||epoch_millis"
			},
			"pay_channel":{
				"type": "integer"
			},
			"pay_channel_zh":{
				"type": "keyword"
			},
			"receiver_phone":{
				"type": "keyword"
			},
			"receiver_name":{
				"type": "keyword"
			},
			"receiver_address_detail":{
				"type": "text",
         		"analyzer": "ik_smart"
			},
			"province":{
				"type": "keyword"
			},
			"city":{
				"type": "keyword"
			},
			"county":{
				"type": "keyword"
			},
			"order_type":{
				"type": "integer"
			},
			"estimate_commission":{
				"type": "float"
			},
			"logistic_company":{
				"type": "keyword"
			},
			"ord_create_time":{
				"type": "date",
         		"format": "yyyy-MM-dd HH:mm:ss||yyyy-MM-dd||epoch_millis"
			},
			"created_at":{
				"type": "date",
         		"format": "yyyy-MM-dd HH:mm:ss||yyyy-MM-dd||epoch_millis"
			},
			"updated_at":{
				"type": "date",
         		"format": "yyyy-MM-dd HH:mm:ss||yyyy-MM-dd||epoch_millis"
			}
		}
	}
}`

type ZhiosOrdersEs struct {
	MasterId              int     `json:"master_id"`
	OrdId                 string  `json:"ord_id"`
	MainOrdId             string  `json:"main_ord_id"`
	StoreOrdId            string  `json:"store_ord_id"`
	GoodsId               string  `json:"goods_id"`
	Uid                   string  `json:"uid"`
	BuyerPhone            string  `json:"buyer_phone"`
	CostPrice             float64 `json:"cost_price"`
	State                 int32   `json:"state"`
	StateZh               string  `json:"state_zh"`
	PayTime               string  `json:"pay_time"`
	PayChannel            int32   `json:"pay_channel"`
	PayChannelZh          string  `json:"pay_channel_zh"`
	ReceiverPhone         string  `json:"receiver_phone"`
	ReceiverName          string  `json:"receiver_name"`
	ReceiverAddressDetail string  `json:"receiver_address_detail"`
	Province              string  `json:"province"`
	City                  string  `json:"city"`
	County                string  `json:"county"`
	OrderType             int32   `json:"order_type"`
	EstimateCommission    float64 `json:"estimate_commission"`
	LogisticCompany       string  `json:"logistic_company"`
	OrdCreateTime         string  `json:"ord_create_time"`
	CreatedAt             string  `json:"created_at"`
	UpdatedAt             string  `json:"updated_at"`
}
